@@ -15,18 +15,23 @@ import Control.Monad.ST as Export
 import Control.Monad.State.Strict as Export
 import Control.Monad.Writer.CPS as Export
 import Data.Bifoldable as Export
-import Data.Bifunctor as Export
 import Data.Bitraversable as Export
 import Data.Bool as Export
+import Data.Coerce as Export
+import Data.Complex as Export
 import Data.Convertible as Export
 import Data.Either as Export
 import Data.Eq as Export
+import Data.Fixed as Export
 import Data.Foldable as Export
 import Data.Function as Export
+import Data.Functor.Compose as Export
 import Data.Hashable as Export
+import Data.Int as Export
+import Data.Kind as Export
 import Data.Maybe as Export
-import Data.Monoid as Export
 import Data.Ord as Export
+import Data.Proxy as Export
 import Data.Ratio as Export
 import Data.String as Export
 import Data.Time as Export
@@ -36,11 +41,17 @@ import Data.Void as Export
 import Data.Word as Export
 import Debug.Pretty.Simple as Export
 import Himari.Prelude.Aeson as Export
+import Himari.Prelude.Arrow as Export
+import Himari.Prelude.Catch as Export
 import Himari.Prelude.Category as Export
+import Himari.Prelude.Data as Export
 import Himari.Prelude.FilePath as Export
 import Himari.Prelude.Generics as Export
+import Himari.Prelude.Monoid as Export
 import Himari.Prelude.Safe as Export
 import Himari.Prelude.Type as Export
+import Himari.Prelude.TypeLevel as Export
+import Numeric.Natural as Export
 import System.Process.Typed as Export
 import Text.Pretty.Simple as Export
 import Text.Show as Export
